==> v1.0.2.zip: homepage/content/author/pcdummy.md <==
---
date: 2018-08-12T00:00:00+01:00
title: René Jochum
description: Is an FOSS enthusiast who has been programming since 2002, currently he loves to develop in Python and Go.
address: "Schmiedgasse 9, 6800 Feldkirch, Austria"
email: rene@jochums.at
phone: 0043 664 750 77 653
pgp: 1B0D 3560 3C4F 372D FF0F CA4E 9E8B 1C32 F5F3 18A9
pgppubfile: /static/author/pcdummy_pub_pgp.asc

img: /static/author/pcdummy_240x240.png
---
## About me

I love to work with Linux, I love Networking I love Programming. If I can FOSS first. Currently my main interest is Cloud computing.

### Knowledge

Programming Languages (in order of preference):

Language      | Years of Knowledge
--------------|-------------------------------------------------------------------------
Python        |      [6+](https://github.com/pcdummy/socketrpc)
Go            |      [5+](https://github.com/pcdummy/golxml)
C++ (with Qt) |      [6+](https://github.com/pcdummy/Warzone-QML-Frontend)
PHP           |      13+
Javascript    |      14+
Visual Basic  |      [15+](http://www.vbarchiv.net/tipps/details.php?id=680)
VB.NET        |      7+
C#            |      [4+](https://github.com/pcdummy/SharpFlame)

Operating Systems: Linux, OS-X, Windows

Languages: German (first language), English (fluent but not perfect)

### OpenSource Activities

#### 2018: LXD Module and States are now part of Salt Fluorine [original PR](https://github.com/saltstack/salt/pull/46231)
Finaly the LXD Module and its States are now part of Saltstack Fluorine. :)

#### 2016 [Presentation at the Linuxday Vorarlberg (German)](https://www.youtube.com/watch?v=0WIyYOsSvQw)
I hold a presentation about Saltstack at the Linuxday Vorarlberg.

#### 2016 - 2017: [saltstack-lxd-formula](https://github.com/saltstack-formulas/lxd-formula)
Working on automatic deployed LXD containers - You say **you want** a Website - **you get** a container with a website in it and ofc all its routing and stuff.

#### 2015 - current: [LXD](https://linuxcontainers.org/lxd/)
Smaller stuff.
Intodruced the new [Storage API](https://github.com/lxc/lxd/commits?author=pcdummy) for BTRFS and big parts of the LVM version.

#### 2009 - current: IRC
In german theres a wording "Girl for everything" - I help where I can.

#### 2010 - 2015: [Warzone 2100](http://www.wz2100.net/)
Hosting and maintenance of the website.
Intodruced the [buildbot](http://buildbot.wz2100.net/).
Introduced a new [Lobby Server](https://github.com/pcdummy/wzlobbyserver-ng) in Python.

#### 2002 - ca. 2006: [Apachefriends](https://www.apachefriends.org) XAMPP
Smaller scripts, Moderation in the forums and smaller work.

#### 2002: vb@rchiv
[.m3u reader](http://www.vbarchiv.net/tipps/details.php?id=680)
[ID3v2 Tag reader](http://www.vbarchiv.net/tipps/details.php?id=676)

### CAREER SUMMARY

#### August 2018 - current: [Webmeisterei GmbH](https://webmeisterei.com)
Working as DevOp

Tools working with:
- Saltstack
- Debian
- Nutanix
- MariaDB Galera Cluster
- Check_MK
- Kubernetes with Rancher
- Gitlab
- borgbackup with borgmatic
- HyCU Backup

#### Mai 2018 - June 2018: [Proxmox Server Solutions GmbH](https://www.proxmox.com/en)
Development in Perl, mainly developed a Client for Proxmox Virtual Environment.

- [pmxc](https://github.com/pcdummy/pmxc)
- [pve-client](https://git.proxmox.com/?p=pve-client.git;a=shortlog)

#### November 2016 – January 2017: [Stiftung Maria Ebene](http://mariaebene.at)
Developing interfaces between Apps (SAP / Filemaker / ELGA uvm.).

- [py-restfmclient](https://github.com/pcdummy/py-restfmclient) python client library for Filemaker over [RESTfm](http://restfm.com)

#### August 2015 – October 2016: [Webmeisterei GmbH](https://webmeisterei.com)
Worked as Plone developer.

#### June 2013 – July 2015: [Stiftung Maria Ebene](http://mariaebene.at)
Apprenticeship as IT Technican over the [FAB](http://www.fab.at), did a lot of Filemaker developements.

#### October 2012 – May 2013: [EPOS Computer](https://www.eposcomputer.com/)
Technical field service as Apple Service Technican and programming.

#### Januar 2012 – June 2012: ITC Energy AG
Filemaker Development of a ERP.
HTML5 2D CAD Tool.

#### Oktober 2008 – December 2011: [JR IT Solutions](http://jrit.at)
Self employed as Software developer and IT Consultant.

#### July 2007 – September 2008: [EPOS Computer](https://www.eposcomputer.com/)
Technical field service as Apple Service Technican and programming.

#### June 2005 – July 2007: Community service + Employment [Stiftung Maria Ebene](http://mariaebene.at)
IT and software developer.

#### Jan 2004 – May 2005: [ABF/Landeskrankenhaus Feldkirch](http://www.lkhf.at/)
Development of MS Access Databases.

==> v1.1.4.zip: homepage/content/author/pcdummy.md <==
---
date: 2021-12-15T00:00:00+01:00
title: René Jochum
description: Is an FOSS enthusiast who has been programming since 2002, currently he loves to develop in Python and Go.
address: Nenzing
email: rene@jochum.dev
phone: +43 664 750 77 653
pgp: 1B0D 3560 3C4F 372D FF0F CA4E 9E8B 1C32 F5F3 18A9
pgppubfile: /static/author/pcdummy_pub_pgp.asc

img: /static/author/pcdummy_240x240.png
---
## About me

I love to work with Linux, I love Networking I love Programming. If I can FOSS first. Currently my main interest is Cloud computing.

### Knowledge

Programming Languages (in order of preference):

Language      | Years of Knowledge
--------------|-------------------------------------------------------------------------
Python        |      [11+](https://github.com/pcdummy/socketrpc)
Go            |      [9+](https://github.com/pcdummy/golxml)
C++ (with Qt) |      [11+](https://github.com/pcdummy/Warzone-QML-Frontend)
PHP           |      18+
Javascript    |      19+
Visual Basic  |      [19+](http://www.vbarchiv.net/tipps/details.php?id=680)
VB.NET        |      12+
C#            |      [8+](https://github.com/pcdummy/SharpFlame)

Operating Systems: Linux, OS-X, Windows

Languages: German (first language), English (fluent but not perfect)

### OpenSource Activities

#### 2022: [MicroLobby - 3rd gen lobbyserver for Warzone 2100](https://github.com/pcdummy/microlobby)

MicroLobby is the next, next gen lobbyserver for Warzone 2100 after wzlobbserver-ng.

#### 2021: lql+api + LetsCheck for CheckMK

A interface to the LQL of CheckMK + a Mobile App written in flutter.

#### 2018: LXD Module and States are now part of Salt Fluorine [original PR](https://github.com/saltstack/salt/pull/46231)

Finaly the LXD Module and its States are now part of Saltstack Fluorine. :)

#### 2016 [Presentation at the Linuxday Vorarlberg (German)](https://www.youtube.com/watch?v=0WIyYOsSvQw)

I hold a presentation about Saltstack at the Linuxday Vorarlberg.

#### 2016 - 2017: [saltstack-lxd-formula](https://github.com/saltstack-formulas/lxd-formula)

Working on automatic deployed LXD containers - You say **you want** a Website - **you get** a container with a website in it and ofc all its routing and stuff.

#### 2015 - ca. 2018: [LXD](https://linuxcontainers.org/lxd/)

Smaller stuff.
Intodruced the new [Storage API](https://github.com/lxc/lxd/commits?author=pcdummy) for BTRFS and big parts of the LVM version.

#### 2009 - current: IRC

In german theres a wording "Girl for everything" - I help where I can under the name "jochum".

#### 2010 - 2015: [Warzone 2100](http://www.wz2100.net/)

Hosting and maintenance of the website.
Intodruced the [buildbot](http://buildbot.wz2100.net/).
Introduced a new [Lobby Server](https://github.com/pcdummy/wzlobbyserver-ng) in Python.

#### 2002 - ca. 2006: [Apachefriends](https://www.apachefriends.org) XAMPP

Smaller scripts, Moderation in the forums and smaller work.

#### 2002: vb@rchiv

[.m3u reader](http://www.vbarchiv.net/tipps/details.php?id=680)
[ID3v2 Tag reader](http://www.vbarchiv.net/tipps/details.php?id=676)

### CAREER SUMMARY

#### Januar 2022 - now: [Jochum Development](https://jochum.dev)

Freelance Developer.

#### August 2018 - Oktober 2021: [Webmeisterei GmbH](https://webmeisterei.com)

Working as DevOp

Tools working with:

- Saltstack
- Debian
- Nutanix
- MariaDB Galera Cluster
- Check_MK
- Kubernetes with Rancher
- Gitlab
- borgbackup with borgmatic
- HyCU Backup

#### Mai 2018 - June 2018: [Proxmox Server Solutions GmbH](https://www.proxmox.com/en)

Development in Perl, mainly developed a Client for Proxmox Virtual Environment.

- [pmxc](https://github.com/pcdummy/pmxc)
- [pve-client](https://git.proxmox.com/?p=pve-client.git;a=shortlog)

#### November 2016 – January 2017: [Stiftung Maria Ebene](http://mariaebene.at)

Developing interfaces between Apps (SAP / Filemaker / ELGA uvm.).

- [py-restfmclient](https://github.com/pcdummy/py-restfmclient) python client library for Filemaker over [RESTfm](http://restfm.com)

#### August 2015 – October 2016: [Webmeisterei GmbH](https://webmeisterei.com)

Worked as Plone developer.

#### June 2013 – July 2015: [Stiftung Maria Ebene](http://mariaebene.at)

Apprenticeship as IT Technican over the [FAB](http://www.fab.at), did a lot of Filemaker developements.

#### October 2012 – May 2013: [EPOS Computer](https://www.eposcomputer.com/)

Technical field service as Apple Service Technican and programming.

#### Januar 2012 – June 2012: ITC Energy AG

Filemaker Development of a ERP.
HTML5 2D CAD Tool.

#### Oktober 2008 – December 2011: [JR IT Solutions](http://jrit.at)

Self employed as Software developer and IT Consultant.

#### July 2007 – September 2008: [EPOS Computer](https://www.eposcomputer.com/)

Technical field service as Apple Service Technican and programming.

#### June 2005 – July 2007: Community service + Employment [Stiftung Maria Ebene](http://mariaebene.at)

IT and software developer.

#### Jan 2004 – May 2005: [ABF/Landeskrankenhaus Feldkirch](http://www.lkhf.at/)

Development of MS Access Databases.
